==> tdesktop-4.8.4-full.tar.gz: tdesktop-4.8.4-full/Telegram/ThirdParty/range-v3/doc/gh-pages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Range-v3", "index.html", [
    [ "User Manual", "index.html", [
      [ "Preface", "index.html#tutorial-preface", [
        [ "Installation", "index.html#tutorial-installation", null ],
        [ "License", "index.html#tutorial-license", null ],
        [ "Supported Compilers", "index.html#tutorial-compilers", null ]
      ] ],
      [ "Quick Start", "index.html#tutorial-quick-start", [
        [ "Views", "index.html#tutorial-views", null ],
        [ "View const-ness", "index.html#autotoc_md6", null ],
        [ "View validity", "index.html#autotoc_md7", null ],
        [ "List of range views", "index.html#autotoc_md8", null ],
        [ "Actions", "index.html#tutorial-actions", null ],
        [ "List of range actions", "index.html#autotoc_md10", null ],
        [ "Utilities", "index.html#tutorial-utilities", [
          [ "Create Custom Views with view_facade", "index.html#autotoc_md12", null ],
          [ "Create Custom Views with view_adaptor", "index.html#autotoc_md13", [
            [ "view_adaptor in details", "index.html#autotoc_md14", null ]
          ] ],
          [ "Create Custom Iterators with basic_iterator", "index.html#autotoc_md15", null ]
        ] ],
        [ "Concept Checking", "index.html#tutorial-concepts", null ],
        [ "Range-v3 and the Future", "index.html#tutorial-future", null ]
      ] ]
    ] ],
    [ "Examples", "md_examples.html", [
      [ "Examples: Algorithms", "md_examples.html#example-algorithms", [
        [ "Hello, Ranges!", "md_examples.html#example-hello", null ],
        [ "any_of, all_of, none_of", "md_examples.html#example-any-all-none", null ],
        [ "count", "md_examples.html#example-count", null ],
        [ "count_if", "md_examples.html#example-count_if", null ],
        [ "find, find_if, find_if_not on sequence containers", "md_examples.html#example-find", null ],
        [ "for_each on sequence containers", "md_examples.html#example-for_each-seq", null ],
        [ "for_each on associative containers", "md_examples.html#example-for_each-assoc", null ],
        [ "is_sorted", "md_examples.html#example-is_sorted", null ]
      ] ],
      [ "Examples: Views", "md_examples.html#example-views", [
        [ "Filter and transform", "md_examples.html#example-filter-transform", null ],
        [ "Generate ints and accumulate", "md_examples.html#example-accumulate-ints", null ],
        [ "Convert a range comprehension to a vector", "md_examples.html#example-comprehension-conversion", null ]
      ] ],
      [ "Examples: Actions", "md_examples.html#example-actions", [
        [ "Remove non-unique elements from a container", "md_examples.html#example-sort-unique", null ]
      ] ],
      [ "Examples: Putting it all together", "md_examples.html#example-gestalt", [
        [ "Calendar", "md_examples.html#example-calendar", null ]
      ] ]
    ] ],
    [ "Release Notes", "release_notes.html", [
      [ "Version 0.11.0 \"Thanks, ISO\"", "release_notes.html#v0-11-0", null ],
      [ "Version 0.10.0 \"To Err is Human\"", "release_notes.html#v0-10-0", null ],
      [ "Version 0.9.1", "release_notes.html#v0-9-1", null ],
      [ "Version 0.9.0 \"Std::ranger Things\"", "release_notes.html#v0-9-0", null ],
      [ "Version 0.5.0", "release_notes.html#v0-5-0", null ],
      [ "Version 0.4.0", "release_notes.html#v0-4-0", null ],
      [ "Version 0.3.7", "release_notes.html#v0-3-7", null ],
      [ "Version 0.3.6", "release_notes.html#v0-3-6", null ],
      [ "Version 0.3.5", "release_notes.html#v0-3-5", null ],
      [ "Version 0.3.0", "release_notes.html#v0-3-0", null ],
      [ "Version 0.2.6", "release_notes.html#v0-2-6", null ],
      [ "Version 0.2.5", "release_notes.html#v0-2-5", null ],
      [ "Version 0.2.4", "release_notes.html#v0-2-4", null ],
      [ "Version 0.2.3", "release_notes.html#v0-2-3", null ],
      [ "Version 0.2.2", "release_notes.html#v0-2-2", null ],
      [ "Version 0.2.1", "release_notes.html#v0-2-1", null ],
      [ "Version 0.2.0", "release_notes.html#v0-2-0", null ],
      [ "Version 0.1.1", "release_notes.html#v0-1-1", null ],
      [ "Version 0.1.0", "release_notes.html#v0-1-0", null ]
    ] ],
    [ "Reference", "modules.html", "modules" ],
    [ "Indexes", "usergroup0.html", [
      [ "Methods", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ],
      [ "Classes", "annotated.html", "annotated" ],
      [ "Files", "files.html", "files" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classranges_1_1sample__view.html#ab60a7eef1bf38e2406fa9bc05ad3e90f",
"equal__range_8hpp.html",
"group__group-algorithms.html#gac1663f9fd1985e4095d958b39b0f4f4e",
"group__group-views.html#gad032e209a7d07f0fa9bad8f7a9677276",
"identity_8hpp.html",
"meta_8hpp.html#ga8d0d695134bd6b94698ae4f1c0d2f553",
"range_2traits_8hpp.html#ga55960f2d90da8a3d53f3a7795a38c138",
"structmeta_1_1compose___3_01_fn0_01_4.html#ac65e09e1dde99fdc928922489ac2dc0f",
"structranges_1_1bind__element_3_01reference__wrapper_3_01_t_01_4_01_4.html#a7a6caef2e0c5829ae329b7ef4fb1723c",
"structranges_1_1experimental_1_1coroutine__owner.html#ae897b895bfbc9d1eb72e30e62974c0e5",
"structranges_1_1move__iterator.html#a0550d63ab6fed5cc93a55100941924d0",
"structranges_1_1semiregular__box.html#a0bc1fb205fe4ac10a10b204f23c28baa",
"structranges_1_1view__interface.html#a97261fec512a0a953c755e7ca4791977",
"structranges_1_1views_1_1take__exactly__base__fn.html",
"view_2take_8hpp.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> tdesktop-5.8.3-full.tar.gz: tdesktop-5.8.3-full/Telegram/ThirdParty/range-v3/doc/gh-pages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Range-v3", "index.html", [
    [ "User Manual", "index.html", [
      [ "Preface", "index.html#tutorial-preface", [
        [ "Installation", "index.html#tutorial-installation", null ],
        [ "License", "index.html#tutorial-license", null ],
        [ "Supported Compilers", "index.html#tutorial-compilers", null ]
      ] ],
      [ "Quick Start", "index.html#tutorial-quick-start", [
        [ "Views", "index.html#tutorial-views", null ],
        [ "View const-ness", "index.html#autotoc_md21", null ],
        [ "View validity", "index.html#autotoc_md22", null ],
        [ "List of range views", "index.html#autotoc_md23", null ],
        [ "Actions", "index.html#tutorial-actions", null ],
        [ "List of range actions", "index.html#autotoc_md25", null ],
        [ "Utilities", "index.html#tutorial-utilities", [
          [ "Create Custom Views with view_facade", "index.html#autotoc_md27", null ],
          [ "Create Custom Views with view_adaptor", "index.html#autotoc_md28", [
            [ "view_adaptor in details", "index.html#autotoc_md29", null ]
          ] ],
          [ "Create Custom Iterators with basic_iterator", "index.html#autotoc_md30", null ]
        ] ],
        [ "Concept Checking", "index.html#tutorial-concepts", null ],
        [ "Range-v3 and the Future", "index.html#tutorial-future", null ]
      ] ]
    ] ],
    [ "Examples", "md_examples.html", [
      [ "Examples: Algorithms", "md_examples.html#example-algorithms", [
        [ "Hello, Ranges!", "md_examples.html#example-hello", null ],
        [ "any_of, all_of, none_of", "md_examples.html#example-any-all-none", null ],
        [ "count", "md_examples.html#example-count", null ],
        [ "count_if", "md_examples.html#example-count_if", null ],
        [ "find, find_if, find_if_not on sequence containers", "md_examples.html#example-find", null ],
        [ "for_each on sequence containers", "md_examples.html#example-for_each-seq", null ],
        [ "for_each on associative containers", "md_examples.html#example-for_each-assoc", null ],
        [ "is_sorted", "md_examples.html#example-is_sorted", null ]
      ] ],
      [ "Examples: Views", "md_examples.html#example-views", [
        [ "Filter and transform", "md_examples.html#example-filter-transform", null ],
        [ "Generate ints and accumulate", "md_examples.html#example-accumulate-ints", null ],
        [ "Convert a range comprehension to a vector", "md_examples.html#example-comprehension-conversion", null ]
      ] ],
      [ "Examples: Actions", "md_examples.html#example-actions", [
        [ "Remove non-unique elements from a container", "md_examples.html#example-sort-unique", null ]
      ] ],
      [ "Examples: Putting it all together", "md_examples.html#example-gestalt", [
        [ "Calendar", "md_examples.html#example-calendar", null ]
      ] ]
    ] ],
    [ "Release Notes", "release_notes.html", [
      [ "Version 0.12.0 \"Dude, Where's My Bored Ape?\"", "release_notes.html#v0-12-0", null ],
      [ "Version 0.11.0 \"Thanks, ISO\"", "release_notes.html#v0-11-0", null ],
      [ "Version 0.10.0 \"To Err is Human\"", "release_notes.html#v0-10-0", null ],
      [ "Version 0.9.1", "release_notes.html#v0-9-1", null ],
      [ "Version 0.9.0 \"Std::ranger Things\"", "release_notes.html#v0-9-0", null ],
      [ "Version 0.5.0", "release_notes.html#v0-5-0", null ],
      [ "Version 0.4.0", "release_notes.html#v0-4-0", null ],
      [ "Version 0.3.7", "release_notes.html#v0-3-7", null ],
      [ "Version 0.3.6", "release_notes.html#v0-3-6", null ],
      [ "Version 0.3.5", "release_notes.html#v0-3-5", null ],
      [ "Version 0.3.0", "release_notes.html#v0-3-0", null ],
      [ "Version 0.2.6", "release_notes.html#v0-2-6", null ],
      [ "Version 0.2.5", "release_notes.html#v0-2-5", null ],
      [ "Version 0.2.4", "release_notes.html#v0-2-4", null ],
      [ "Version 0.2.3", "release_notes.html#v0-2-3", null ],
      [ "Version 0.2.2", "release_notes.html#v0-2-2", null ],
      [ "Version 0.2.1", "release_notes.html#v0-2-1", null ],
      [ "Version 0.2.0", "release_notes.html#v0-2-0", null ],
      [ "Version 0.1.1", "release_notes.html#v0-1-1", null ],
      [ "Version 0.1.0", "release_notes.html#v0-1-0", null ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ]
      ] ]
    ] ],
    [ "Concepts", "concepts.html", "concepts" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"accumulate_8hpp.html",
"conceptranges_1_1range.html",
"group__group-algorithms.html#ga8b388e16334836ff0f36d9cfc251734a",
"group__lazy__query.html#gae589e49d658820f9ffd7bffbcddde074",
"ref_8hpp.html",
"structranges_1_1invoke__fn.html",
"structranges_1_1views_1_1take__last__base__fn.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
